@@ -1,14 +1,30 @@
 package Pcore::Whois::Data;
 
-use Pcore;
+use Pcore -const, -export => {    #
+    CONST => [qw[$WHOIS_STATUS_OK $WHOIS_STATUS_NO_SERVER $WHOIS_STATUS_NETWORK $WHOIS_STATUS_BANNED $WHOIS_STATUS_NO_CONTENT]],
+};
 
-our $TLD = {    #
+const our $WHOIS_STATUS_OK         => 200;
+const our $WHOIS_STATUS_NO_SERVER  => 404;
+const our $WHOIS_STATUS_NETWORK    => 500;
+const our $WHOIS_STATUS_BANNED     => 501;
+const our $WHOIS_STATUS_NO_CONTENT => 502;
+
+const our $NOT_AVAIL_DOMAIN => 'cwxtwtqcuduvo78hr0dbrfxpuhv8gmtm';
+
+our $TLD = {                      #
     'web.za' => 'web-whois.registry.net.za',
     'org.za' => 'org-whois.registry.net.za',
     'net.za' => 'net-whois.registry.net.za',
     'co.za'  => 'whois.registry.net.za',
 };
 
+our $TLD_NOT_AVAIL = {
+    edu => 1,
+    gov => 1,
+    mil => 1,
+};
+
 our $SERVER = {
     'whois.arin.org'         => { req_format  => 'n + <: QUERY :>' . $CRLF },
     'whois.denic.de'         => { req_format  => '-C UTF-8 -T dn,ace <: QUERY :>' . $CRLF },
